@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -601,6 +601,8 @@ def _doit(arglist):
 
 			for mod, (properties, options) in information.items():
 				if name in properties:
+					if not properties[name].cli_enabled:
+						continue
 					if properties[name].multivalue:
 						input.setdefault(name, [])
 						if value:
@@ -614,6 +616,8 @@ def _doit(arglist):
 			name, delim, value = val.partition('=')
 			for mod, (properties, options) in information.items():
 				if name in properties:
+					if not properties[name].cli_enabled:
+						continue
 					if properties[name].multivalue:
 						append.setdefault(name, [])
 						if value:
@@ -628,6 +632,8 @@ def _doit(arglist):
 			value = value or None
 			for mod, (properties, options) in information.items():
 				if name in properties:
+					if not properties[name].cli_enabled:
+						continue
 					if properties[name].multivalue:
 						if value is None:
 							remove[name] = value
@@ -954,6 +960,8 @@ class CLI(object):
 				if not univention.admin.modules.virtual(module_name):
 					object.open()
 					for key, value in sorted(object.items()):
+						if not module.property_descriptions[key].show_in_lists:
+							continue
 						s = module.property_descriptions[key].syntax
 						if module.property_descriptions[key].multivalue:
 							for v in value:
